{% extends "!pydata_sphinx_theme/layout.html" %}
{%- block extrahead %}
    <link rel="stylesheet" href="{{ pathto('_static/css/default.css', 1) }}"/>
    <link rel="stylesheet" href="{{ pathto('_static/css/custom.css', 1) }}"/>
{% endblock %}
